@@ -21,28 +21,19 @@
 
 void screenshooter_take_and_output_screenshot (ScreenshotData *sd)
 {
-  GdkPixbuf *screenshot = 
+  GdkPixbuf *screenshot =
     screenshooter_take_screenshot (sd->region, sd->delay);
-  
+
   if (sd->action == SAVE)
     {
-      if (sd->show_save_dialog == 1)
+      if (sd->screenshot_dir == NULL)
         {
-          gchar *home = g_strdup (DEFAULT_SAVE_DIRECTORY);
-          
-          screenshooter_save_screenshot (screenshot, 
-                                         1, 
-                                         home);
-                                         
-          if (home != NULL)
-            g_free (home);                                         
-        }
-      else
-        {
-          screenshooter_save_screenshot (screenshot, 
-                                         0, 
-                                         sd->screenshot_dir);
+          sd->screenshot_dir = g_strdup (DEFAULT_SAVE_DIRECTORY);
         }
+
+      screenshooter_save_screenshot (screenshot,
+                                     sd->show_save_dialog,
+                                     sd->screenshot_dir);
     }
   else if (sd->action == CLIPBOARD)
     {
@@ -52,22 +43,22 @@ void screenshooter_take_and_output_screenshot (ScreenshotData *sd)
   else
     {
       gchar *tempdir = g_strdup (g_get_tmp_dir ());
-      
+
       gchar *screenshot_path =
-        screenshooter_save_screenshot (screenshot, 
-                                       FALSE, 
+        screenshooter_save_screenshot (screenshot,
+                                       FALSE,
                                        tempdir);
       if (screenshot_path != NULL)
         {
           screenshooter_open_screenshot (screenshot_path, sd->app);
           g_free (screenshot_path);
         }
-        
+
       if (tempdir != NULL)
         g_free (tempdir);
     }
   #endif
-  
+
   g_object_unref (screenshot);
 }
-      
+
