@@ -39,18 +39,24 @@ static GdkWindow
 *get_active_window (GdkScreen *screen, gboolean *needs_unref)
 {
   GdkWindow *window, *window2;
+
+  TRACE ("Get the active window");
   
   window = gdk_screen_get_active_window (screen);
             
   /* If there is no active window, we fallback to the whole screen. */      
   if (window == NULL)
     {
+      TRACE ("No active window, fallback to the root window");
+
       window = gdk_get_default_root_window ();
       *needs_unref = FALSE;
     }
   else if (gdk_window_get_type_hint (window) == GDK_WINDOW_TYPE_HINT_DESKTOP)
     {
       /* If the active window is the desktop, grab the whole screen */
+      TRACE ("The active window is the desktop, fallback to the root window");
+
       g_object_unref (window);
                     
       window = gdk_get_default_root_window ();
@@ -59,6 +65,8 @@ static GdkWindow
   else
     {
       /* Else we find the toplevel window to grab the decorations. */
+      TRACE ("Active window is a normal window, grab the toplevel window");
+
       window2 = gdk_window_get_toplevel (window);
       
       g_object_unref (window);
@@ -76,17 +84,28 @@ static GdkPixbuf
 {
   gint x_orig, y_orig;
   gint width, height;
+  
   GdkPixbuf *screenshot;
   GdkWindow *root;
+  
   GdkRectangle *rectangle = g_new0 (GdkRectangle, 1);
+  
+  GdkCursor *cursor;
+  GdkPixbuf *cursor_pixbuf;
     
   /* Get the root window */
+  TRACE ("Get the root window");
+  
   root = gdk_get_default_root_window ();
+
+  TRACE ("Get the frame extents");
   
   gdk_window_get_frame_extents (window, rectangle);
     
   /* Don't grab thing offscreen. */
-    
+
+  TRACE ("Make sure we don't grab things offscreen");
+  
   x_orig = rectangle->x;
   y_orig = rectangle->y;
   width  = rectangle->width;
@@ -114,10 +133,65 @@ static GdkPixbuf
   
   /* Take the screenshot from the root GdkWindow, to grab things such as
    * menus. */
+
+  TRACE ("Grab the screenshot");
+  
   screenshot = gdk_pixbuf_get_from_drawable (NULL, root, NULL,
                                              x_orig, y_orig, 0, 0,
                                              width, height);
-  
+
+  /* Add the mouse pointer to the grabbed screenshot */
+
+  TRACE ("Get the mouse cursor and its image");
+
+  cursor = gdk_cursor_new_for_display (gdk_display_get_default (), GDK_LEFT_PTR);
+  cursor_pixbuf = gdk_cursor_get_image (cursor);
+
+  if (cursor_pixbuf != NULL)
+    {
+      GdkRectangle rectangle_window, rectangle_cursor;
+      gint cursorx, cursory, xhot, yhot;
+
+      TRACE ("Get the coordinates of the cursor");
+ 	
+      gdk_window_get_pointer (window, &cursorx, &cursory, NULL);
+
+      TRACE ("Get the hot-spot x and y values");
+      
+      sscanf (gdk_pixbuf_get_option (cursor_pixbuf, "x_hot"), "%d", &xhot);
+      sscanf (gdk_pixbuf_get_option (cursor_pixbuf, "y_hot"), "%d", &yhot);
+
+      /* rectangle_window stores the window coordinates */
+      rectangle_window.x = x_orig;
+      rectangle_window.y = y_orig;
+      rectangle_window.width = width;
+      rectangle_window.height = height;
+      
+      /* rectangle_cursor stores the cursor coordinates */
+      rectangle_cursor.x = cursorx + x_orig;
+      rectangle_cursor.y = cursory + y_orig;
+      rectangle_cursor.width = gdk_pixbuf_get_width (cursor_pixbuf);
+      rectangle_cursor.height = gdk_pixbuf_get_height (cursor_pixbuf);
+      
+      /* see if the pointer is inside the window */
+      if (gdk_rectangle_intersect (&rectangle_window, &rectangle_cursor, &rectangle_cursor))
+        {
+          TRACE ("Compose the two pixbufs");
+
+          gdk_pixbuf_composite (cursor_pixbuf, screenshot,
+                                cursorx - xhot, cursory - yhot,
+                                rectangle_cursor.width, rectangle_cursor.height,
+                                cursorx - xhot, cursory - yhot,
+                                1.0, 1.0,
+                                GDK_INTERP_BILINEAR,
+                                255);
+        }
+        
+      g_object_unref (cursor_pixbuf);
+    }
+
+  gdk_cursor_unref (cursor);
+
   return screenshot;                                             
 }
 
@@ -129,6 +203,8 @@ static GdkPixbuf
   GdkPixbuf *screenshot = NULL;
  
   /* Get root window */
+  TRACE ("Get the root window");
+  
   GdkWindow *root_window =  gdk_get_default_root_window ();
   
   GdkGCValues gc_values;
@@ -155,6 +231,8 @@ static GdkPixbuf
   
   /*Set up graphics context for a XOR rectangle that will be drawn as 
    * the user drags the mouse */
+  TRACE ("Initialize the graphics context");
+  
   gc_values.function           = GDK_XOR;
   gc_values.line_width         = 0;
   gc_values.line_style         = GDK_LINE_SOLID;
@@ -172,6 +250,8 @@ static GdkPixbuf
   gdk_gc_set_rgb_bg_color (gc, &gc_black);
   
   /* Change cursor to cross-hair */
+  TRACE ("Set the cursor");
+  
   grabstatus = gdk_pointer_grab (root_window, FALSE, mask,
                                  NULL, xhair_cursor, GDK_CURRENT_TIME);
   
@@ -188,7 +268,11 @@ static GdkPixbuf
       switch (event->type)
         {
           /* Start dragging the rectangle out */
+     
           case GDK_BUTTON_PRESS:
+
+            TRACE ("Start dragging the rectangle");
+            
             x = x2 = x1 = event->button.x;
             y = y2 = y1 = event->button.y;
             w = 0; h = 0;
@@ -196,34 +280,44 @@ static GdkPixbuf
             break;
           
           /* Finish dragging the rectangle out */
-         case GDK_BUTTON_RELEASE:
-           if (pressed)
-             {
-               if (w > 0 && h > 0)
-                 {
-                   /* Remove the rectangle drawn previously */
-                   gdk_draw_rectangle (root_window, 
-                                       gc, 
-                                       FALSE, 
-                                       x, y, w, h);
-                   done = TRUE;
-                 } 
-               else 
-                 {
-                   /* The user has not dragged the mouse, start again */
+          case GDK_BUTTON_RELEASE:
+            if (pressed)
+              {
+                if (w > 0 && h > 0)
+                  {
+                    /* Remove the rectangle drawn previously */
+
+                    TRACE ("Remove the rectangle drawn previously");
+                    
+                    gdk_draw_rectangle (root_window, 
+                                        gc, 
+                                        FALSE, 
+                                        x, y, w, h);
+                    done = TRUE;
+                  } 
+                else 
+                  {
+                    /* The user has not dragged the mouse, start again */
+
+                    TRACE ("Mouse was not dragged, start agan");
                    
-                   pressed = FALSE;
-                 }
-             }
-           break;
+                    pressed = FALSE;
+                  }
+              }
+          break;
           
           /* The user is moving the mouse */
           case GDK_MOTION_NOTIFY:
             if (pressed)
               {
+                TRACE ("Mouse is moving");
+
                 if (w > 0 && h > 0)
                
                 /* Remove the rectangle drawn previously */
+
+                TRACE ("Remove the rectangle drawn previously");
+                
                 gdk_draw_rectangle (root_window, 
                                     gc, 
                                     FALSE, 
@@ -238,6 +332,9 @@ static GdkPixbuf
                 h = ABS (y2 - y1);
 
                 /* Draw  the rectangle as the user drags  the mouse */
+
+                TRACE ("Draw the new rectangle");
+                
                 if (w > 0 && h > 0)
                   gdk_draw_rectangle (root_window, 
                                       gc, 
@@ -253,13 +350,18 @@ static GdkPixbuf
       
       gdk_event_free (event);
     }
-  
+ 
   if (grabstatus == GDK_GRAB_SUCCESS) 
     {
+      TRACE ("Ungrab the pointer");
+
       gdk_pointer_ungrab(GDK_CURRENT_TIME);
     }
   
   /* Get the screenshot's pixbuf */
+
+  TRACE ("Get the pixbuf for the screenshot");
+  
   screenshot = gdk_pixbuf_get_from_drawable (NULL, root_window, NULL,
                                              x, y, 0, 0, w, h);
   
@@ -302,23 +404,31 @@ GdkPixbuf *screenshooter_take_screenshot (gint region, gint delay)
   /* Get the window/desktop we want to screenshot*/  
   if (region == FULLSCREEN)
     {
+      TRACE ("We grab the entire screen");
+
       window = gdk_get_default_root_window ();
       needs_unref = FALSE;
     } 
   else if (region == ACTIVE_WINDOW)
     {
+      TRACE ("We grab the active window");
+
       window = get_active_window (screen, &needs_unref);      
     }
       
   if (region == FULLSCREEN || region == ACTIVE_WINDOW)
     {
+      TRACE ("Get the screenshot of the given window");
+
       screenshot = get_window_screenshot (window);
-      
+          
       if (needs_unref)
 	      g_object_unref (window);
     }
   else if (region == SELECT)
     {
+      TRACE ("Let the user select the region to screenshot");
+
       screenshot = get_rectangle_screenshot ();
     }
 
@@ -337,6 +447,8 @@ screenshooter_copy_to_clipboard (GdkPixbuf *screenshot)
 {
   GtkClipboard *clipboard;
 
+  TRACE ("Adding the image to the clipboard...");
+
   clipboard = gtk_clipboard_get_for_display (gdk_display_get_default(), 
                                              GDK_SELECTION_CLIPBOARD);
   gtk_clipboard_set_image (clipboard, screenshot);
@@ -367,10 +479,14 @@ screenshooter_read_rc_file (gchar               *file,
   
   if (file != NULL)
     {
+      TRACE ("Open the rc file");
+
       rc = xfce_rc_simple_open (file, TRUE);
 
       if (rc != NULL)
         {
+          TRACE ("Read the entries");
+
           delay = xfce_rc_read_int_entry (rc, "delay", 0);
               
           region = xfce_rc_read_int_entry (rc, "region", FULLSCREEN);
@@ -394,11 +510,15 @@ screenshooter_read_rc_file (gchar               *file,
                                           "screenshot_dir", 
                                           DEFAULT_SAVE_DIRECTORY));
         }
+
+      TRACE ("Close the rc file");
       
       xfce_rc_close (rc);
     }
    
   /* And set the sd values */
+  TRACE ("Set the values of the struct");
+  
   sd->delay = delay;
   sd->region = region;
   sd->action = action;
@@ -423,9 +543,13 @@ screenshooter_write_rc_file (gchar               *file,
   
   g_return_if_fail (file != NULL);
 
+  TRACE ("Open the rc file");
+
   rc = xfce_rc_simple_open (file, FALSE);
   
   g_return_if_fail (rc != NULL);
+
+  TRACE ("Write the entries.");
   
   xfce_rc_write_int_entry (rc, "delay", sd->delay);
   xfce_rc_write_int_entry (rc, "region", sd->region);
@@ -437,6 +561,8 @@ screenshooter_write_rc_file (gchar               *file,
   xfce_rc_write_entry (rc, "app", sd->app);
   #endif
 
+  TRACE ("Flush and close the rc file");
+
   xfce_rc_flush (rc);
   
   xfce_rc_close (rc);
@@ -455,18 +581,24 @@ screenshooter_open_screenshot (gchar *screenshot_path,
 {
   if (screenshot_path != NULL)
     {
+      TRACE ("Path was != NULL");
+
       if (!g_str_equal (application, "none"))
         {
           gchar *command = 
             g_strconcat (application, " ", screenshot_path, NULL);
     
           GError *error = NULL;
+
+          TRACE ("Launch the command");
           
           /* Execute the command and show an error dialog if there was 
           * an error. */
           if (!xfce_exec_on_screen (gdk_screen_get_default (), command, 
                                     FALSE, TRUE, &error))
             {
+              TRACE ("An error occured");
+
               xfce_err (error->message);
               g_error_free (error);
             }
